@@ -2,7 +2,7 @@
 #' Calculate age-standardized incidence rates
 #'
 #' @param df dataframe in wide format
-#' @param dattype can be "zfkd" or "seer" or empty. Will set default variable names from dataset.
+#' @param dattype can be "zfkd" or "seer" or NULL. Will set default variable names if dattype is "seer" or "zfkd". Default is NULL.
 #' @param std_pop can be either "ESP2013, ESP1976, WHO1960
 #' @param truncate_std_pop if TRUE standard population will be truncated for all age-groups that do not occur in df
 #' @param futime_src can be either "refpop" or "cohort". Default is "refpop".
@@ -73,7 +73,7 @@
 
 asir <-
   function(df,
-           dattype = "zfkd",
+           dattype = NULL,
            std_pop = "ESP2013",
            truncate_std_pop = FALSE,
            futime_src = "refpop",
@@ -141,6 +141,7 @@ asir <-
       )
     } 
     
+    if(!is.null(dattype)){
     ### setting default var names and values for SEER data --> still need to update to final names!
     if (dattype == "seer") {
       if (is.null(region_var)) {
@@ -209,6 +210,15 @@ asir <-
         futime_var <- rlang::ensym(futime_var)
       }
     }
+    } else{
+      # ensym if no dattype is given
+      region_var <- rlang::ensym(region_var)
+      age_var <- rlang::ensym(age_var)
+      sex_var <- rlang::ensym(sex_var)
+      year_var <- rlang::ensym(year_var)
+      site_var <- rlang::ensym(site_var)
+      futime_var <- rlang::ensym(futime_var)
+    }
     
     #setting standard population
     
